You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by da...@apache.org on 2016/08/01 04:31:57 UTC

svn commit: r1754701 [12/13] - in /openoffice/branches/gbuild-reintegration: ./ ext_libraries/apr-util/ ext_libraries/apr/ ext_sources/ main/ main/accessibility/inc/accessibility/standard/ main/autodoc/inc/ary/idl/ main/avmedia/source/framework/ main/b...

Modified: openoffice/branches/gbuild-reintegration/main/sdext/source/pdfimport/pdfparse/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sdext/source/pdfimport/pdfparse/makefile.mk?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sdext/source/pdfimport/pdfparse/makefile.mk (original)
+++ openoffice/branches/gbuild-reintegration/main/sdext/source/pdfimport/pdfparse/makefile.mk Mon Aug  1 04:31:52 2016
@@ -36,7 +36,7 @@ EXTERNAL_WARNINGS_NOT_ERRORS=TRUE
 CFLAGS+=-DSYSTEM_ZLIB
 .ENDIF
 
-ENVCFLAGS += -DBOOST_SPIRIT_USE_OLD_NAMESPACE
+ENVCFLAGS += -DBOOST_SPIRIT_USE_OLD_NAMESPACE -DBOOST_SYSTEM_NO_DEPRECATED
 
 # --- Files --------------------------------------------------------
 

Modified: openoffice/branches/gbuild-reintegration/main/set_soenv.in
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/set_soenv.in?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/set_soenv.in (original)
+++ openoffice/branches/gbuild-reintegration/main/set_soenv.in Mon Aug  1 04:31:52 2016
@@ -24,7 +24,7 @@
 #---------------------------------------------------------------------------
 # Description:
 # set_soenv generates a file that contains all necessary 
-# environment variables for the build proces of OpenOffice
+# environment variables for the build process of OpenOffice
 # on Linux, NetBSD, Solaris, Windows NT and Mac OS X/Darwin.
 #
 # Program steps.
@@ -954,7 +954,7 @@ if ($platform =~ m/cygwin/)
    {
       $JAVA_LIB             = $JAVA_HOME.$LIB;
    }
-   # Import SystemDrive enviroment variable
+   # Import SystemDrive environment variable
    use Env qw(SYSTEMDRIVE);
    # Change $SYSTEMDRIVE to lower case.
    $SYSTEMDRIVE          = lc $SYSTEMDRIVE;
@@ -1380,7 +1380,9 @@ $SOLARINC             = $I.$cur_dir.
                         $I.'$SOLARVER'.$ds.'$INPATH'.$INC.
                         $I.'$SOLARENV'.$ds.'$OUTPATH'.$INC.
                         $I.'$SOLARENV'.$INC.
-                        $I.'$SRC_ROOT'.$ds."res";
+                        $I.'$SRC_ROOT'.$ds."res".
+                        $I.'$SRC_ROOT'.$ds."tools".$INC.
+                        $I.'$SRC_ROOT'.$ds."comphelper".$INC;
 
 if ($platform =~ m/solaris|linux|osf1|freebsd|netbsd/)
 {
@@ -1491,7 +1493,7 @@ elsif ($platform =~ m/darwin/)
     $GUIBASE  = "aqua";
 }
 else
-{  AddWarning( "set_soenv", "$platform not configured for system dependant include dir" );
+{  AddWarning( "set_soenv", "$platform not configured for system dependent include dir" );
 }
 
 #
@@ -2490,7 +2492,7 @@ sub WinFormat
 
 #----------------------------------------------------------
 # Function name: WinPath
-# Description:   Reformat a $sep seperated path using DOS paths.
+# Description:   Reformat a $sep separated path using DOS paths.
 # Arguments:     1. Variable (string)
 #                2. Separaror (string)
 # Return value:  Reformatted String

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/docfile.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/docfile.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/docfile.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/docfile.hxx Mon Aug  1 04:31:52 2016
@@ -317,7 +317,7 @@ public:
 
 	SAL_DLLPRIVATE sal_Bool SignContents_Impl( sal_Bool bScriptingContent, const ::rtl::OUString& aODFVersion, sal_Bool bHasValidDocumentSignature );
 
-	// the following two methods must be used and make sence only during saving currently
+	// the following two methods must be used and make sense only during saving currently
 	// TODO/LATER: in future the signature state should be controlled by the medium not by the document
 	//             in this case the methods will be used generally, and might need to be renamed
 	SAL_DLLPRIVATE sal_uInt16 GetCachedSignatureState_Impl();

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/filedlghelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/filedlghelper.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/filedlghelper.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/filedlghelper.hxx Mon Aug  1 04:31:52 2016
@@ -265,7 +265,7 @@ public:
     // XDialogClosedListener methods
     virtual void SAL_CALL   DialogClosed( const ::com::sun::star::ui::dialogs::DialogClosedEvent& _rEvent );
 
-	// retrieves the top-most file picker - i.e. the instance which is currently beeing executed
+	// retrieves the top-most file picker - i.e. the instance which is currently being executed
 	static ::com::sun::star::uno::Reference< ::com::sun::star::ui::dialogs::XFilePicker >
 							GetTopMostFilePicker( );
 

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/styfitem.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/styfitem.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/styfitem.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/inc/sfx2/styfitem.hxx Mon Aug  1 04:31:52 2016
@@ -102,7 +102,7 @@ public:
 
 	/** updates the images of all single SfxStyleFamilyItems with new images from the given resource
 
-		<p>The resource must contain a local image lists, with the id beeing the integer equivalent for the
+		<p>The resource must contain a local image lists, with the id being the integer equivalent for the
 		requested bitmap mode, incremented by 1.</p>
 
 		<p>Usually, you will use the same resource which originally constructed the object.</p>

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/appl/appopen.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/appl/appopen.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/appl/appopen.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/appl/appopen.cxx Mon Aug  1 04:31:52 2016
@@ -267,7 +267,7 @@ private:
     try
     {
         // check the encryption data
-        // if the data correct is the stream will be opened successfuly
+        // if the data correct is the stream will be opened successfully
         // and immediately closed
         ::comphelper::OStorageHelper::SetCommonStorageEncryptionData( mxStorage, rEncryptionData );
 

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/bitset.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/bitset.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/bitset.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/bitset.cxx Mon Aug  1 04:31:52 2016
@@ -172,7 +172,7 @@ BitSet::BitSet( sal_uInt16* pArray, sal_
 	}
 	else
 	{
-		// initalize emtpy set
+		// initialize emtpy set
 		nBlocks = 0;
 		pBitmap = 0;
 	}

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/fltfnc.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/fltfnc.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/fltfnc.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/bastyp/fltfnc.cxx Mon Aug  1 04:31:52 2016
@@ -878,7 +878,7 @@ const SfxFilter* SfxFilterMatcherIter::N
 }
 
 /*---------------------------------------------------------------
-    helper to build own formated string from given stringlist by
+    helper to build own formatted string from given stringlist by
     using given seperator
   ---------------------------------------------------------------*/
 ::rtl::OUString implc_convertStringlistToString( const ::com::sun::star::uno::Sequence< ::rtl::OUString >& lList     ,

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/filtergrouping.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/filtergrouping.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/partwnd.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/partwnd.cxx Mon Aug  1 04:31:52 2016
@@ -96,7 +96,7 @@ SfxPartChildWnd_Impl::~SfxPartChildWnd_I
 //        pWin->ReleaseChildWindow_Impl();
 /*
     // Release frame and window.
-    // If frame reference is valid here ... start dieing from inside by calling dispose().
+    // If frame reference is valid here ... start dying from inside by calling dispose().
     SetFrame( NULL );
     pWindow = NULL;
 */

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/DocumentMetadataAccess.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/DocumentMetadataAccess.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/DocumentMetadataAccess.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/DocumentMetadataAccess.cxx Mon Aug  1 04:31:52 2016
@@ -817,7 +817,7 @@ DocumentMetadataAccess::DocumentMetadata
         const IXmlIdRegistrySupplier & i_rRegistrySupplier)
     : m_pImpl(new DocumentMetadataAccess_Impl(i_xContext, i_rRegistrySupplier))
 {
-    // no initalization: must call loadFrom...
+    // no initialization: must call loadFrom...
 }
 
 DocumentMetadataAccess::DocumentMetadataAccess(

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docfile.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docfile.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docfile.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docfile.cxx Mon Aug  1 04:31:52 2016
@@ -318,7 +318,7 @@ public:
 	sal_Bool 		m_bRemoveBackup;
 	::rtl::OUString m_aBackupURL;
 
-	// the following member is changed and makes sence only during saving
+	// the following member is changed and makes sense only during saving
 	// TODO/LATER: in future the signature state should be controlled by the medium not by the document
 	//             in this case the member will hold this information
 	sal_uInt16		m_nSignatureState;
@@ -1203,7 +1203,7 @@ sal_Bool SfxMedium::LockOrigFileOnDemand
                             }
                             catch ( ucb::InteractiveIOException& e )
                             {
-                                // exception means that the lock file can not be successfuly accessed
+                                // exception means that the lock file can not be successfully accessed
                                 // in this case it should be ignored if system file locking is anyway active
                                 if ( bUseSystemLock || !IsOOoLockFileUsed() )
                                 {
@@ -1235,7 +1235,7 @@ sal_Bool SfxMedium::LockOrigFileOnDemand
                             }
                             catch ( uno::Exception& )
                             {
-                                // exception means that the lock file can not be successfuly accessed
+                                // exception means that the lock file can not be successfully accessed
                                 // in this case it should be ignored if system file locking is anyway active
                                 if ( bUseSystemLock || !IsOOoLockFileUsed() )
                                 {
@@ -1994,7 +1994,7 @@ void SfxMedium::Transfer_Impl()
 		aNameURL = pImp->pTempFile->GetURL();
 	else if ( aLogicName.Len() && pImp->m_bSalvageMode )
 	{
-		// makes sence only in case logic name is set
+		// makes sense only in case logic name is set
 		if ( !::utl::LocalFileHelper::ConvertPhysicalNameToURL( aName, aNameURL ) )
 			OSL_ENSURE( sal_False, "The medium name is not convertable!\n" );
 	}
@@ -2404,7 +2404,7 @@ void SfxMedium::GetLockingStream_Impl()
 
             if ( !pImp->pTempFile && !aName.Len() )
             {
-                // the medium is still based on the original file, it makes sence to initialize the streams
+                // the medium is still based on the original file, it makes sense to initialize the streams
                 if ( pImp->m_xLockingStream.is() )
                     pImp->xStream = pImp->m_xLockingStream;
 

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docvor.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docvor.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docvor.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/docvor.cxx Mon Aug  1 04:31:52 2016
@@ -1649,7 +1649,7 @@ String SfxOrganizeDlg_Impl::GetPath_Impl
    [Return value]                 Empty sequence when users have clicked
                                   'Cancel', a sequence just containing one
                                   file name with path when they have
-                                  choosed one file or a sequence containing
+                                  chose one file or a sequence containing
                                   path and file names without path
 */
 

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/objstor.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/objstor.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/objstor.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/objstor.cxx Mon Aug  1 04:31:52 2016
@@ -1890,7 +1890,7 @@ sal_Bool SfxObjectShell::DisconnectStora
                 // contents, the storag will be broken
                 xOptStorage->attachToURL( aBackupURL, sal_True );
 
-                // the storage is successfuly attached to backup, thus it it owned by the document not by the medium
+                // the storage is successfully attached to backup, thus it it owned by the document not by the medium
                 rSrcMedium.CanDisposeStorage_Impl( sal_False );
                 bResult = sal_True;
             }
@@ -1932,7 +1932,7 @@ sal_Bool SfxObjectShell::ConnectTmpStora
             uno::Reference< embed::XOptimizedStorage > xOptStorage( xStorage, uno::UNO_QUERY_THROW );
             xOptStorage->writeAndAttachToStream( uno::Reference< io::XStream >() );
 
-            // the storage is successfuly disconnected from the original sources, thus the medium must not dispose it
+            // the storage is successfully disconnected from the original sources, thus the medium must not dispose it
             if ( pMediumArg )
                 pMediumArg->CanDisposeStorage_Impl( sal_False );
 
@@ -2672,7 +2672,7 @@ sal_Bool SfxObjectShell::DoSave_Impl( co
         SetError( GetMedium()->Unpack_Impl( pRetrMedium->GetPhysicalName() ), ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
 */
 
-    // an interaction handler here can aquire only in case of GUI Saving
+    // an interaction handler here can acquire only in case of GUI Saving
     // and should be removed after the saving is done
     com::sun::star::uno::Reference< XInteractionHandler > xInteract;
     SFX_ITEMSET_ARG( pArgs, pxInteractionItem, SfxUnoAnyItem, SID_INTERACTIONHANDLER, sal_False );

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/sfxbasemodel.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/sfxbasemodel.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/sfxbasemodel.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/doc/sfxbasemodel.cxx Mon Aug  1 04:31:52 2016
@@ -1637,7 +1637,7 @@ void SAL_CALL SfxBaseModel::storeSelf( c
 			// stored in normal way.
 			if ( !hasLocation() || getLocation().compareToAscii( "private:", 8 ) == 0 )
 			{
-				// actually in this very rare case only UI parameters have sence
+				// actually in this very rare case only UI parameters have sense
 				// TODO/LATER: should be done later, after integration of sb19
                 bRet = m_pData->m_pObjectShell->DoSave()
                     && m_pData->m_pObjectShell->DoSaveCompleted();

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/view/frame.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/view/frame.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/view/frame.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/view/frame.cxx Mon Aug  1 04:31:52 2016
@@ -849,7 +849,7 @@ void SfxFrame::CreateWorkWindow_Impl()
 
 	if ( IsInPlace() )
 	{
-		// this makes sence only for inplace activated objects
+		// this makes sense only for inplace activated objects
 		try
 		{
 	    	Reference < XChild > xChild( GetCurrentDocument()->GetModel(), UNO_QUERY );

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/view/ipclient.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/view/ipclient.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/view/ipclient.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/view/ipclient.cxx Mon Aug  1 04:31:52 2016
@@ -999,7 +999,7 @@ ErrCode SfxInPlaceClient::DoVerb( long n
 				{
 					if ( nVerb == 0 || nVerb == embed::EmbedVerbs::MS_OLEVERB_OPEN )
 					{
-						// a workaround for the default verb, usually makes sence for alien objects
+						// a workaround for the default verb, usually makes sense for alien objects
 						try
 						{
 							m_pImp->m_xObject->doVerb( -9 ); // open own view, a workaround verb that is not visible

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/view/viewprn.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/view/viewprn.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/view/viewprn.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/view/viewprn.cxx Mon Aug  1 04:31:52 2016
@@ -271,7 +271,7 @@ void SfxPrinterController::printPage( in
         }
         catch( lang::IllegalArgumentException& )
         {
-            // don't care enough about nonexistant page here
+            // don't care enough about nonexistent page here
             // to provoke a crash
         }
     }

Modified: openoffice/branches/gbuild-reintegration/main/shell/inc/internal/registry.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/shell/inc/internal/registry.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/shell/inc/internal/registry.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/shell/inc/internal/registry.hxx Mon Aug  1 04:31:52 2016
@@ -49,7 +49,7 @@ bool SetRegistryKey(HKEY RootKey, const
 bool DeleteRegistryKey(HKEY RootKey, const char* KeyName);
 
 /** May be used to determine if the specified registry key has subkeys
-	The function returns true on success else if an error occures false
+	The function returns true on success else if an error occurs false
 */
 bool HasSubkeysRegistryKey(HKEY RootKey, const char* KeyName, bool& bResult);
 

Modified: openoffice/branches/gbuild-reintegration/main/shell/inc/internal/zipfile.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/shell/inc/internal/zipfile.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/shell/inc/internal/zipfile.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/shell/inc/internal/zipfile.hxx Mon Aug  1 04:31:52 2016
@@ -135,7 +135,7 @@ public:
 	*/
 	DirectoryPtr_t GetDirectory() const;
 
-	/** Convinience query function may even realized with 
+	/** Convenience query function may even realized with 
 		iterating over a ZipFileDirectory returned by
 		GetDirectory
 	*/

Modified: openoffice/branches/gbuild-reintegration/main/shell/source/all/zipfile/zipfile.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/shell/source/all/zipfile/zipfile.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/shell/source/all/zipfile/zipfile.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/shell/source/all/zipfile/zipfile.cxx Mon Aug  1 04:31:52 2016
@@ -207,7 +207,7 @@ ZipFile::DirectoryPtr_t ZipFile::GetDire
 	return dir;
 }
 
-/** Convinience query function may even realized with 
+/** Convenience query function may even realized with 
 	iterating over a ZipFileDirectory returned by
 	GetDirectory */
 bool ZipFile::HasContent(const std::string& ContentName) const

Modified: openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/infotips/infotips.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/infotips/infotips.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/infotips/infotips.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/infotips/infotips.cxx Mon Aug  1 04:31:52 2016
@@ -269,7 +269,7 @@ HRESULT STDMETHODCALLTYPE CInfoTip::GetI
             msg += meta_info_accessor.getTagData( META_INFO_DESCRIPTION );
         }
 
-        //display midified time formated into locale representation.
+        //display midified time formatted into locale representation.
         if ( iso8601_date_to_local_date(meta_info_accessor.getTagData(META_INFO_MODIFIED )).length() > 0)
         {
 			if ( msg != EMPTY_STRING )

Modified: openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/util/registry.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/util/registry.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/util/registry.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/shell/source/win32/shlxthandler/util/registry.cxx Mon Aug  1 04:31:52 2016
@@ -137,7 +137,7 @@ bool DeleteRegistryKey(HKEY RootKey, con
 }
 
 /** May be used to determine if the specified registry key has subkeys
-	The function returns true on success else if an error occures false
+	The function returns true on success else if an error occurs false
 */
 bool HasSubkeysRegistryKey(HKEY RootKey, const char* KeyName, /* out */ bool& bResult)
 {

Modified: openoffice/branches/gbuild-reintegration/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx Mon Aug  1 04:31:52 2016
@@ -481,7 +481,7 @@ class MovingSlideChange : public SlideCh
     
 public:
     /** Create a new SlideChanger, for the given entering slide
-        bitmaps, which performes a moving slide change effect
+        bitmaps, which performs a moving slide change effect
         
         @param rLeavingDirection
         Direction vector. The move is performed along this

Modified: openoffice/branches/gbuild-reintegration/main/solenv/bin/deliver.pl
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/bin/deliver.pl?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/bin/deliver.pl (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/bin/deliver.pl Mon Aug  1 04:31:52 2016
@@ -200,7 +200,7 @@ sub do_dos
         print "DOS: $command\n";
     }
     else {
-        # HACK: remove MACOSX stuff which is wrongly labled with dos
+        # HACK: remove MACOSX stuff which is wrongly labeled with dos
         # better: fix broken d.lst
         return if ( $command =~ /MACOSX/ );
         $command =~ s#/#\\#g if $^O eq 'MSWin32';

Modified: openoffice/branches/gbuild-reintegration/main/solenv/bin/download_external_dependencies.pl
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/bin/download_external_dependencies.pl?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/bin/download_external_dependencies.pl (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/bin/download_external_dependencies.pl Mon Aug  1 04:31:52 2016
@@ -507,92 +507,45 @@ sub DownloadFile ($$$)
     my $URL = shift;
     my $checksum = shift;
 
-    my $filename = File::Spec->catfile($ENV{'TARFILE_LOCATION'}, $name);
-
-    my $temporary_filename = $filename . ".part";
-
-    print "downloading to $temporary_filename\n";
-    my $out;
-    open $out, ">$temporary_filename";
-    binmode($out);
-
-    # Prepare checksum
-    my $digest;
-    if (defined $checksum && $checksum->{'type'} eq "SHA1")
-    {
-        # Use SHA1 only when explicitly requested (by the presence of a "SHA1=..." line.)
-        $digest = Digest::SHA->new("1");
-    }
-    elsif ( ! defined $checksum || $checksum->{'type'} eq "MD5")
+    if (defined $checksum)
     {
-        # Use MD5 when explicitly requested or when no checksum type is given.
-        $digest = Digest::MD5->new();
+        system(
+            $ENV{'JAVAINTERPRETER'},
+            "-cp",
+            File::Spec->catfile(
+                File::Spec->catfile($ENV{'SOLARENV'}, $ENV{'INPATH'}),
+                "class"),
+            "AOOJavaDownloader",
+            $name,
+            $URL,
+            $checksum->{'type'},
+            $checksum->{'value'});
     }
     else
     {
-        die "checksum type ".$checksum->{'type'}." is not supported";
+        system(
+            $ENV{'JAVAINTERPRETER'},
+            "-cp",
+            File::Spec->catfile(
+                File::Spec->catfile($ENV{'SOLARENV'}, $ENV{'INPATH'}),
+                "class"),
+            "AOOJavaDownloader",
+            $name,
+            $URL);
     }
 
-    # Download the extension.
-    my $success = 0;
-
-    my $agent = LWP::UserAgent->new();
-    $agent->env_proxy;
-    my $response = $agent->get($URL);
-
-    $success = $response->is_success;
-    if ($success)
-    {
-        my $content = $response->content;
-        open $out, ">$temporary_filename";
-        binmode($out);
-        print $out $content;
-        $digest->add($content);
-    }
-    else
+    my $rc = $? >> 8;
+    if ($rc == 0)
     {
-        print "download from $URL failed (" . $response->status_line . ")\n";
+        return 1;
     }
-    close($out);
-
-    # When download was successful then check the checksum and rename the .part file
-    # into the actual extension name.
-    if ($success)
+    elsif ($rc == 1)
     {
-        my $file_checksum = $digest->hexdigest();
-        if (defined $checksum)
-        {
-            if ($checksum->{'value'} eq $file_checksum)
-            {
-                printf("%s checksum is OK\n", $checksum->{'type'});
-            }
-            else
-            {
-                unlink($temporary_filename);
-                printf("    %s checksum does not match (%s instead of %s)\n",
-                       $checksum->{'type'},
-                       $file_checksum,
-                       $checksum->{'value'});
-                return 0;
-            }
-        }
-        else
-        {
-            # The datafile does not contain a checksum to match against.
-            # Display the one that was calculated for the downloaded file so that
-            # it can be integrated manually into the data file.
-            printf("checksum not given, md5 of file is %s\n", $file_checksum);
-            $filename = File::Spec->catfile($ENV{'TARFILE_LOCATION'}, $file_checksum . "-" . $name);
-        }
-
-        rename($temporary_filename, $filename) || die "can not rename $temporary_filename to $filename";
-        return 1;
+        return 0;
     }
     else
     {
-        unlink($temporary_filename);
-        print "    download failed\n";
-        return 0;
+        exit $rc;
     }
 }
 

Modified: openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/ExtensionsLst.pm
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/ExtensionsLst.pm?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/ExtensionsLst.pm (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/ExtensionsLst.pm Mon Aug  1 04:31:52 2016
@@ -468,70 +468,19 @@ sub Download (@)
     {
         my ($protocol, $name, $URL, $md5sum) = @{$entry};
 
-        # Open a .part file for writing.
-        my $filename = File::Spec->catfile($download_path, $name);
-        my $temporary_filename = $filename . ".part";
-        print "downloading to $temporary_filename\n";
-        open my $out, ">$temporary_filename";
-        binmode($out);
+        system(
+            $ENV{'JAVAINTERPRETER'},
+            "-cp",
+            File::Spec->catfile(
+                File::Spec->catfile($ENV{'SOLARENV'}, $ENV{'INPATH'}),
+                "class"),
+            "AOOJavaDownloader",
+            $name,
+            $URL,
+            'MD5',
+            $md5sum);
 
-        # Prepare md5
-        my $md5 = Digest::MD5->new();
-        
-        # Download the extension.
-        my $agent = LWP::UserAgent->new();
-        $agent->timeout(120);
-        $agent->show_progress(1);
-        my $last_was_redirect = 0;
-        $agent->add_handler('response_redirect'
-                            => sub{
-                                $last_was_redirect = 1;
-                                return;
-                            });
-        $agent->add_handler('response_data'
-                            => sub{
-                                if ($last_was_redirect)
-                                {
-                                    $last_was_redirect = 0;
-                                    # Throw away the data we got so far.
-                                    $md5->reset();
-                                    close $out;
-                                    open $out, ">$temporary_filename";
-                                    binmode($out);
-                                }
-                                my($response,$agent,$h,$data)=@_;
-                                print $out $data;
-                                $md5->add($data);
-                            });
-        my $response = $agent->get($URL);
-        close $out;
-
-        # When download was successful then check the md5 checksum and rename the .part file
-        # into the actual extension name.
-        if ($response->is_success())
-        {
-            if (defined $md5sum && length($md5sum)==32)
-            {
-                my $file_md5 = $md5->hexdigest();
-                if ($md5sum eq $file_md5)
-                {
-                    print "md5 is OK\n";
-                }
-                else
-                {
-                    unlink($temporary_filename) if ! $Debug;
-                    die "downloaded file has the wrong md5 checksum: $file_md5 instead of $md5sum";
-                }
-            }
-            else
-            {
-                print "md5 is not present\n";
-                printf "   is %s, length is %d\n", $md5sum, length(md5sum);
-            }
-            
-            rename($temporary_filename, $filename) || die "can not rename $temporary_filename to $filename";
-        }
-        else
+        if ($? != 0)
         {
             die "failed to download $URL";
         }

Modified: openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/patch/FileOperations.pm
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/patch/FileOperations.pm?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/patch/FileOperations.pm (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/patch/FileOperations.pm Mon Aug  1 04:31:52 2016
@@ -184,7 +184,7 @@ sub Check ($)
             }
             if ( -f $destination_filename && ! -w $destination_filename)
             {
-                # Destination file aleady exists but can not be replaced.
+                # Destination file already exists but can not be replaced.
                 push @error_messages, sprintf("compress destination file %s exists but can not be replaced", $destination_filename);
             }
         }

Modified: openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/systemactions.pm
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/systemactions.pm?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/systemactions.pm (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/bin/modules/installer/systemactions.pm Mon Aug  1 04:31:52 2016
@@ -91,7 +91,7 @@ sub create_directory
 					}
 					else
 					{
-						$infoline = "\Error: \"$directory\" could not be created. Even the parent directory \"$parentdir\" does not exist and could not be created.\n";
+						$infoline = "Error: \"$directory\" could not be created. Even the parent directory \"$parentdir\" does not exist and could not be created.\n";
 						$installer::logger::Lang->print($infoline);
 						if ( -d $parentdir )
 						{
@@ -211,7 +211,7 @@ sub create_directory_with_privileges
 					}
 					else
 					{
-						$infoline = "\Error: \"$directory\" could not be created. Even the parent directory \"$parentdir\" does not exist and could not be created.\n";
+						$infoline = "Error: \"$directory\" could not be created. Even the parent directory \"$parentdir\" does not exist and could not be created.\n";
 						$installer::logger::Lang->print($infoline);
 						if ( -d $parentdir )
 						{

Modified: openoffice/branches/gbuild-reintegration/main/solenv/gbuild/GoogleTest.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/gbuild/GoogleTest.mk?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/gbuild/GoogleTest.mk (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/gbuild/GoogleTest.mk Mon Aug  1 04:31:52 2016
@@ -27,6 +27,8 @@
 # in non-product builds, ensure that tools-based assertions do not pop up as message box, but are routed to the shell
 DBGSV_ERROR_OUT := shell
 export DBGSV_ERROR_OUT
+DISABLE_SAL_DBGBOX := 1
+export DISABLE_SAL_DBGBOX
 
 # defined by platform
 #  gb_CppunitTest_TARGETTYPE

Modified: openoffice/branches/gbuild-reintegration/main/solenv/inc/os2gcci.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/solenv/inc/os2gcci.mk?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/solenv/inc/os2gcci.mk (original)
+++ openoffice/branches/gbuild-reintegration/main/solenv/inc/os2gcci.mk Mon Aug  1 04:31:52 2016
@@ -163,7 +163,6 @@ MODULES_WITH_WARNINGS := \
     starmath \
     svx \
     sw \
-    writerperfect \
     xmlsecurity
 
 

Modified: openoffice/branches/gbuild-reintegration/main/soltools/cpp/_getopt.c
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/soltools/cpp/_getopt.c?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/soltools/cpp/_getopt.c (original)
+++ openoffice/branches/gbuild-reintegration/main/soltools/cpp/_getopt.c Mon Aug  1 04:31:52 2016
@@ -54,7 +54,7 @@ int
             }
     }
     optopt = c = argv[optind][sp];
-    if (c == ':' || (cp = strchr(opts, c)) == 0)
+    if (c == ':' || (cp = strchr(opts, c)) == NULL)
     {
         ERR(": illegal option -- ", c);
         if (argv[optind][++sp] == '\0')
@@ -86,7 +86,7 @@ int
             sp = 1;
             optind++;
         }
-        optarg = 0;
+        optarg = NULL;
     }
     return c;
 }

Modified: openoffice/branches/gbuild-reintegration/main/soltools/cpp/_lex.c
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/soltools/cpp/_lex.c?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/soltools/cpp/_lex.c (original)
+++ openoffice/branches/gbuild-reintegration/main/soltools/cpp/_lex.c Mon Aug  1 04:31:52 2016
@@ -535,7 +535,7 @@ continue2:
 					else
 					{
 	                    runelen = 1;
-                        s->lineinc = 0;;
+                        s->lineinc = 0;
                         tp->type = COMMENT;
 						tp->flag |= XTWS;
 					}

Modified: openoffice/branches/gbuild-reintegration/main/soltools/cpp/_mcrvalid.c
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/soltools/cpp/_mcrvalid.c?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/soltools/cpp/_mcrvalid.c (original)
+++ openoffice/branches/gbuild-reintegration/main/soltools/cpp/_mcrvalid.c Mon Aug  1 04:31:52 2016
@@ -35,7 +35,7 @@
 void
 mvl_init(MacroValidatorList	* out_pValidators)
 {
-	out_pValidators->pFirst = 0;
+	out_pValidators->pFirst = NULL;
 	out_pValidators->nextFreeIdentifier = 1;
 }
 
@@ -45,7 +45,7 @@ mvl_destruct(MacroValidatorList	* out_pV
 	MacroValidator * pV = out_pValidators->pFirst;
 	MacroValidator * pDel;
 	for ( pDel = out_pValidators->pFirst;
-		  pDel != 0;
+		  pDel != NULL;
 		  pDel = pV )
 	{
 		pV = pV->pNext;
@@ -71,7 +71,7 @@ mvl_add( MacroValidatorList *	inout_pVal
 	MacroValidator * pNew = new(MacroValidator);
 	pNew->pMacro = in_pMacro;
 
-	if (in_pTokenWhereMacroBecomesValid == 0)
+	if (in_pTokenWhereMacroBecomesValid == NULL)
 	{
 		pNew->nTokenWhereMacroBecomesValid = INVALID_TILL_ENDOFROW;
 	}
@@ -111,10 +111,10 @@ mvl_check(	MacroValidatorList * inout_pV
 {
 	MacroValidator * pV;			/* Running pointer */
 	MacroValidator * pCheckedOnes;  /* Here new list is built.  */
-	pCheckedOnes = 0;
+	pCheckedOnes = NULL;
 
 	for ( pV = inout_pValidators->pFirst;
-		  pV != 0;
+		  pV != NULL;
 		  pV = inout_pValidators->pFirst )
 	{
 		inout_pValidators->pFirst = pV->pNext;

Modified: openoffice/branches/gbuild-reintegration/main/soltools/cpp/_nlist.c
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/soltools/cpp/_nlist.c?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/soltools/cpp/_nlist.c (original)
+++ openoffice/branches/gbuild-reintegration/main/soltools/cpp/_nlist.c Mon Aug  1 04:31:52 2016
@@ -96,7 +96,7 @@ void
             kwdefined = np;
             np->val = NAME;
             np->vp = &deftr;
-            np->ap = 0;
+            np->ap = NULL;
         }
     }
 }

Modified: openoffice/branches/gbuild-reintegration/main/soltools/mkdepend/main.c
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/soltools/mkdepend/main.c?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/soltools/mkdepend/main.c (original)
+++ openoffice/branches/gbuild-reintegration/main/soltools/mkdepend/main.c Mon Aug  1 04:31:52 2016
@@ -633,9 +633,9 @@ char *base_name(file)
         if ( *p == '/' ||  *p == '\\') {
             file = p + 1;
             break;
-        };
+        }
         p--;
-    };
+    }
 	return(file);
 }
 
@@ -774,7 +774,7 @@ void convert_slashes(path)
         for (ptr = (char*)path; *ptr; ++ptr)
             if (*ptr == '\\')
                 *ptr = '/';
-    };
+    }
 #else
     (void)path;
 #endif
@@ -793,7 +793,7 @@ char* append_slash(path)
             strcat(new_string, "\\");
         else
             strcat(new_string, "/");
-    };
+    }
     return new_string;
 }
 

Modified: openoffice/branches/gbuild-reintegration/main/svtools/source/filter/exportdialog.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/svtools/source/filter/exportdialog.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/svtools/source/filter/exportdialog.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/svtools/source/filter/exportdialog.cxx Mon Aug  1 04:31:52 2016
@@ -1313,8 +1313,6 @@ void ExportDialog::updatePreview()
 
 void ExportDialog::updateControls()
 {
-	GetGraphicStream();
-
 	// Size Controls
 	if ( !mbIsPixelFormat )
 	{
@@ -1364,6 +1362,8 @@ void ExportDialog::updateControls()
 	if ( maSbCompression.IsVisible() )
 		maSbCompression.SetThumbPos( maNfCompression.GetValue() );
 
+	GetGraphicStream();
+
 	// updating estimated size
 	sal_Int64 nRealFileSize( mpTempStream->Tell() );
 	if ( mbIsPixelFormat )

Modified: openoffice/branches/gbuild-reintegration/main/sysui/desktop/debian/postinst
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sysui/desktop/debian/postinst?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sysui/desktop/debian/postinst (original)
+++ openoffice/branches/gbuild-reintegration/main/sysui/desktop/debian/postinst Mon Aug  1 04:31:52 2016
@@ -162,7 +162,6 @@ application/vnd.stardivision.draw; %PREF
 application/x-stardraw; %PREFIX -view %s
 application/vnd.oasis.opendocument.database; %PREFIX -view %s
 application/vnd.sun.xml.base; %PREFIX -view %s
-application/vnd.writerperfect; %PREFIX -view %s
 application/wordperfect5.1; %PREFIX -view %s
 application/x-wordperfect; %PREFIX -view %s
 application/wordperfect; %PREFIX -view %s

Modified: openoffice/branches/gbuild-reintegration/main/sysui/desktop/redhat/redhat-menus.spec
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sysui/desktop/redhat/redhat-menus.spec?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sysui/desktop/redhat/redhat-menus.spec (original)
+++ openoffice/branches/gbuild-reintegration/main/sysui/desktop/redhat/redhat-menus.spec Mon Aug  1 04:31:52 2016
@@ -233,7 +233,6 @@ application/vnd.stardivision.draw; %unix
 application/x-stardraw; %unixfilename -view %s
 application/vnd.oasis.opendocument.database; %unixfilename -view %s
 application/vnd.sun.xml.base; %unixfilename -view %s
-application/vnd.writerperfect; %unixfilename -view %s
 application/wordperfect5.1; %unixfilename -view %s
 application/x-wordperfect; %unixfilename -view %s
 application/wordperfect; %unixfilename -view %s

Modified: openoffice/branches/gbuild-reintegration/main/sysui/desktop/solaris/mailcap
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sysui/desktop/solaris/mailcap?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/sysui/desktop/solaris/mailcap (original)
+++ openoffice/branches/gbuild-reintegration/main/sysui/desktop/solaris/mailcap Mon Aug  1 04:31:52 2016
@@ -84,7 +84,6 @@ application/vnd.stardivision.draw; %PREF
 application/x-stardraw; %PREFIX -view %s
 application/vnd.sun.xml.base; %PREFIX -view %s
 application/vnd.oasis.opendocument.database; %PREFIX -view %s
-application/vnd.writerperfect; %PREFIX -view %s
 application/wordperfect5.1; %PREFIX -view %s
 application/x-wordperfect; %PREFIX -view %s
 application/wordperfect; %PREFIX -view %s

Modified: openoffice/branches/gbuild-reintegration/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java (original)
+++ openoffice/branches/gbuild-reintegration/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java Mon Aug  1 04:31:52 2016
@@ -466,7 +466,7 @@ public class ConvwatchGUI extends javax.
             h = _aLabel.getHeight();
         }
 
-        // dont access here anything to "Event Swing Thread"
+        // don't access here anything to "Event Swing Thread"
         @Override
         public ImageIcon doInBackground()
         {

Modified: openoffice/branches/gbuild-reintegration/main/toolkit/src2xml/include.lst
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/toolkit/src2xml/include.lst?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/toolkit/src2xml/include.lst (original)
+++ openoffice/branches/gbuild-reintegration/main/toolkit/src2xml/include.lst Mon Aug  1 04:31:52 2016
@@ -194,7 +194,6 @@
 ../../filter/inc
 ../../filter/unxlngi6.pro/inc
 ../../extras/unxlngi6.pro/inc
-../../writerperfect/unxlngi6.pro/inc
 ../../toolkit/inc
 ../../toolkit/unxlngi6.pro/inc
 ../../officecfg/unxlngi6.pro/inc

Modified: openoffice/branches/gbuild-reintegration/main/tools/source/generic/poly2.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/tools/source/generic/poly2.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/tools/source/generic/poly2.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/tools/source/generic/poly2.cxx Mon Aug  1 04:31:52 2016
@@ -198,6 +198,7 @@ void PolyPolygon::Remove( sal_uInt16 nPo
 {
 	DBG_CHKTHIS( PolyPolygon, NULL );
 	DBG_ASSERT( nPos < Count(), "PolyPolygon::Remove(): nPos >= nSize" );
+	if ( nPos >= Count() ) return; // not removable
 
 	if ( mpImplPolyPolygon->mnRefCount > 1 )
 	{
@@ -218,6 +219,7 @@ void PolyPolygon::Replace( const Polygon
 {
 	DBG_CHKTHIS( PolyPolygon, NULL );
 	DBG_ASSERT( nPos < Count(), "PolyPolygon::Replace(): nPos >= nSize" );
+	if ( nPos >= Count() ) return; // not replaceable	
 
 	if ( mpImplPolyPolygon->mnRefCount > 1 )
 	{
@@ -283,61 +285,61 @@ void PolyPolygon::Optimize( sal_uIntPtr
 
 	if(nOptimizeFlags && Count())
 	{
-        // #115630# ImplDrawHatch does not work with beziers included in the polypolygon, take care of that
-        bool bIsCurve(false);
+		// #115630# ImplDrawHatch does not work with beziers included in the polypolygon, take care of that
+		bool bIsCurve(false);
 
-        for(sal_uInt16 a(0); !bIsCurve && a < Count(); a++)
-        {
-            if((*this)[a].HasFlags())
-            {
-                bIsCurve = true;
-            }
-        }
-
-        if(bIsCurve)
-        {
-            OSL_ENSURE(false, "Optimize does *not* support curves, falling back to AdaptiveSubdivide()...");
-            PolyPolygon aPolyPoly;
-
-            AdaptiveSubdivide(aPolyPoly);
-            aPolyPoly.Optimize(nOptimizeFlags, pData);
-            *this = aPolyPoly;
-        }
-        else
-        {
-		    double		fArea;
-		    const sal_Bool	bEdges = ( nOptimizeFlags & POLY_OPTIMIZE_EDGES ) == POLY_OPTIMIZE_EDGES;
-		    sal_uInt16		nPercent = 0;
-
-		    if( bEdges )
-		    {
-			    const Rectangle aBound( GetBoundRect() );
-
-			    fArea = ( aBound.GetWidth() + aBound.GetHeight() ) * 0.5;
-			    nPercent = pData ? pData->GetPercentValue() : 50;
-			    nOptimizeFlags &= ~POLY_OPTIMIZE_EDGES;
-		    }
-
-		    // watch for ref counter
-		    if( mpImplPolyPolygon->mnRefCount > 1 )
-		    {
-			    mpImplPolyPolygon->mnRefCount--;
-			    mpImplPolyPolygon = new ImplPolyPolygon( *mpImplPolyPolygon );
-		    }
-
-		    // Optimize polygons
-		    for( sal_uInt16 i = 0, nPolyCount = mpImplPolyPolygon->mnCount; i < nPolyCount; i++ )
-		    {
-			    if( bEdges )
-			    {
-				    mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( POLY_OPTIMIZE_NO_SAME );
-				    Polygon::ImplReduceEdges( *( mpImplPolyPolygon->mpPolyAry[ i ] ), fArea, nPercent );
-			    }
-
-			    if( nOptimizeFlags )
-				    mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( nOptimizeFlags, pData );
-		    }
-        }
+		for(sal_uInt16 a(0); !bIsCurve && a < Count(); a++)
+		{
+			if((*this)[a].HasFlags())
+			{
+				bIsCurve = true;
+			}
+		}
+
+		if(bIsCurve)
+		{
+			OSL_ENSURE(false, "Optimize does *not* support curves, falling back to AdaptiveSubdivide()...");
+			PolyPolygon aPolyPoly;
+
+			AdaptiveSubdivide(aPolyPoly);
+			aPolyPoly.Optimize(nOptimizeFlags, pData);
+			*this = aPolyPoly;
+		}
+		else
+		{
+			double		fArea;
+			const sal_Bool	bEdges = ( nOptimizeFlags & POLY_OPTIMIZE_EDGES ) == POLY_OPTIMIZE_EDGES;
+			sal_uInt16		nPercent = 0;
+
+			if( bEdges )
+			{
+				const Rectangle aBound( GetBoundRect() );
+
+				fArea = ( aBound.GetWidth() + aBound.GetHeight() ) * 0.5;
+				nPercent = pData ? pData->GetPercentValue() : 50;
+				nOptimizeFlags &= ~POLY_OPTIMIZE_EDGES;
+			}
+
+			// watch for ref counter
+			if( mpImplPolyPolygon->mnRefCount > 1 )
+			{
+				mpImplPolyPolygon->mnRefCount--;
+				mpImplPolyPolygon = new ImplPolyPolygon( *mpImplPolyPolygon );
+			}
+
+			// Optimize polygons
+			for( sal_uInt16 i = 0, nPolyCount = mpImplPolyPolygon->mnCount; i < nPolyCount; i++ )
+			{
+				if( bEdges )
+				{
+					mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( POLY_OPTIMIZE_NO_SAME );
+					Polygon::ImplReduceEdges( *( mpImplPolyPolygon->mpPolyAry[ i ] ), fArea, nPercent );
+				}
+
+				if( nOptimizeFlags )
+					mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( nOptimizeFlags, pData );
+			}
+		}
 	}
 }
 
@@ -390,53 +392,53 @@ void PolyPolygon::GetXOR( const PolyPoly
 
 void PolyPolygon::ImplDoOperation( const PolyPolygon& rPolyPoly, PolyPolygon& rResult, sal_uIntPtr nOperation ) const
 { 
-    // Convert to B2DPolyPolygon, temporarily. It might be
-    // advantageous in the future, to have a PolyPolygon adaptor that
-    // just simulates a B2DPolyPolygon here...
-    basegfx::B2DPolyPolygon aMergePolyPolygonA( getB2DPolyPolygon() );
-    basegfx::B2DPolyPolygon aMergePolyPolygonB( rPolyPoly.getB2DPolyPolygon() );
-
-    // normalize the two polypolygons before. Force properly oriented
-    // polygons. 
-    aMergePolyPolygonA = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonA );
-    aMergePolyPolygonB = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonB );
+	// Convert to B2DPolyPolygon, temporarily. It might be
+	// advantageous in the future, to have a PolyPolygon adaptor that
+	// just simulates a B2DPolyPolygon here...
+	basegfx::B2DPolyPolygon aMergePolyPolygonA( getB2DPolyPolygon() );
+	basegfx::B2DPolyPolygon aMergePolyPolygonB( rPolyPoly.getB2DPolyPolygon() );
+
+	// normalize the two polypolygons before. Force properly oriented
+	// polygons. 
+	aMergePolyPolygonA = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonA );
+	aMergePolyPolygonB = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonB );
 
 	switch( nOperation )
-    {
-        // All code extracted from svx/source/svdraw/svedtv2.cxx
-        // -----------------------------------------------------
-
-        case POLY_CLIP_UNION:
-        {
-            // merge A and B (OR)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationOr(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-
-        case POLY_CLIP_DIFF:
-        {
-            // subtract B from A (DIFF)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationDiff(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-
-        case POLY_CLIP_XOR:
-        {
-            // compute XOR between poly A and B
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationXor(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-
-        default:
-        case POLY_CLIP_INT:
-        {
-            // cut poly 1 against polys 2..n (AND)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationAnd(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-    }
+	{
+		// All code extracted from svx/source/svdraw/svedtv2.cxx
+		// -----------------------------------------------------
+
+		case POLY_CLIP_UNION:
+		{
+			// merge A and B (OR)
+			aMergePolyPolygonA = basegfx::tools::solvePolygonOperationOr(aMergePolyPolygonA, aMergePolyPolygonB);
+			break;
+		}
+
+		case POLY_CLIP_DIFF:
+		{
+			// subtract B from A (DIFF)
+			aMergePolyPolygonA = basegfx::tools::solvePolygonOperationDiff(aMergePolyPolygonA, aMergePolyPolygonB);
+			break;
+		}
+
+		case POLY_CLIP_XOR:
+		{
+			// compute XOR between poly A and B
+			aMergePolyPolygonA = basegfx::tools::solvePolygonOperationXor(aMergePolyPolygonA, aMergePolyPolygonB);
+			break;
+		}
+
+		default:
+		case POLY_CLIP_INT:
+		{
+			// cut poly 1 against polys 2..n (AND)
+			aMergePolyPolygonA = basegfx::tools::solvePolygonOperationAnd(aMergePolyPolygonA, aMergePolyPolygonB);
+			break;
+		}
+	}
 
-    rResult = PolyPolygon( aMergePolyPolygonA );
+	rResult = PolyPolygon( aMergePolyPolygonA );
 }
 
 // -----------------------------------------------------------------------

Modified: openoffice/branches/gbuild-reintegration/main/tools/source/stream/stream.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/tools/source/stream/stream.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/tools/source/stream/stream.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/tools/source/stream/stream.cxx Mon Aug  1 04:31:52 2016
@@ -1128,38 +1128,59 @@ sal_Bool SvStream::ReadCsvLine( String&
     {
         const sal_Unicode* pSeps = rFieldSeparators.GetBuffer();
         xub_StrLen nLastOffset = 0;
-        xub_StrLen nQuotes = 0;
+        bool isQuoted = false;
+        bool isFieldStarting = true;
         while (!IsEof() && rStr.Len() < STRING_MAXLEN)
         {
+            bool wasQuote = false;
             bool bBackslashEscaped = false;
-            const sal_Unicode *p, *pStart;
-            p = pStart = rStr.GetBuffer();
+            const sal_Unicode *p;
+            p = rStr.GetBuffer();
             p += nLastOffset;
             while (*p)
             {
-                if (nQuotes)
+                if (isQuoted)
                 {
                     if (*p == cFieldQuote && !bBackslashEscaped)
-                        ++nQuotes;
-                    else if (bAllowBackslashEscape)
+                        wasQuote = !wasQuote;
+                    else
                     {
-                        if (*p == '\\')
-                            bBackslashEscaped = !bBackslashEscaped;
-                        else
-                            bBackslashEscaped = false;
+                        if (bAllowBackslashEscape)
+                        {
+                            if (*p == '\\')
+                                bBackslashEscaped = !bBackslashEscaped;
+                            else
+                                bBackslashEscaped = false;
+                        }
+                        if (wasQuote)
+                        {
+                            wasQuote = false;
+                            isQuoted = false;
+                            if (lcl_UnicodeStrChr( pSeps, *p ))
+                                isFieldStarting = true;
+                        }
                     }
                 }
-                else if (*p == cFieldQuote && (p == pStart ||
-                            lcl_UnicodeStrChr( pSeps, p[-1])))
-                    nQuotes = 1;
-                // A quote character inside a field content does not start
-                // a quote.
+                else
+                {
+                    if (isFieldStarting)
+                    {
+                        isFieldStarting = false;
+                        if (*p == cFieldQuote)
+                            isQuoted = true;
+                        else if (lcl_UnicodeStrChr( pSeps, *p ))
+                            isFieldStarting = true;
+                    }
+                    else if (lcl_UnicodeStrChr( pSeps, *p ))
+                        isFieldStarting = true;
+                }
                 ++p;
             }
 
-            if (nQuotes % 2 == 0)
-                break;
-            else
+            if (wasQuote)
+                isQuoted = false;
+
+            if (isQuoted)
             {
                 nLastOffset = rStr.Len();
                 String aNext;
@@ -1167,6 +1188,8 @@ sal_Bool SvStream::ReadCsvLine( String&
                 rStr += sal_Unicode(_LF);
                 rStr += aNext;
             }
+            else
+                break;
         }
     }
     return nError == SVSTREAM_OK;

Modified: openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/odma/odma.h
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/odma/odma.h?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/odma/odma.h (original)
+++ openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/odma/odma.h Mon Aug  1 04:31:52 2016
@@ -1,4 +1,4 @@
-/* odma.h - Definitions, prototypes, etc. for Open Document Managment API
+/* odma.h - Definitions, prototypes, etc. for Open Document Management API
 	(ODMA) version 2.0.
                OPEN DOCUMENT MANAGEMENT API LICENSE 1.0
                      
@@ -119,7 +119,7 @@ typedef int ODMSTATUS;
 #define ODM_E_FAIL			1		/* Unspecified failure */
 #define ODM_E_CANCEL		2		/* Action was cancelled at user's request */
 #define ODM_E_NODMS			3		/* DMS not registered */
-#define ODM_E_CANTINIT		4		/* DMS failed to initalize */
+#define ODM_E_CANTINIT		4		/* DMS failed to initialize */
 #define ODM_E_VERSION		5		/* DMS doesn't support the requested 
 									           version of ODMA */
 #define ODM_E_APPSELECT		6        /* User has indicated that he wants to use 

Modified: openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_content.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_content.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_content.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_content.cxx Mon Aug  1 04:31:52 2016
@@ -2035,7 +2035,7 @@ void Content::transfer(
 
     if ( ( rInfo.SourceURL.getLength() < TDOC_URL_SCHEME_LENGTH + 2 ) )
     {
-        // Invaild length (to short).
+        // Invalid length (to short).
         ucbhelper::cancelCommandExecution(
             uno::makeAny( ucb::InteractiveBadTransferURLException(
                             rtl::OUString(),

Modified: openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_uri.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_uri.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_uri.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/tdoc/tdoc_uri.cxx Mon Aug  1 04:31:52 2016
@@ -55,7 +55,7 @@ void Uri::init() const
         // Check for proper length: must be at least length of <sheme>:/
         if ( ( m_aUri.getLength() < TDOC_URL_SCHEME_LENGTH + 2 ) )
         {
-            // Invaild length (to short).
+            // Invalid length (to short).
             return;
         }
 
@@ -65,7 +65,7 @@ void Uri::init() const
         if ( !aScheme.equalsAsciiL(
                 RTL_CONSTASCII_STRINGPARAM( TDOC_URL_SCHEME ) ) )
         {
-            // Invaild scheme.
+            // Invalid scheme.
             return;
         }
 
@@ -75,14 +75,14 @@ void Uri::init() const
         if ( m_aUri.getStr()[ TDOC_URL_SCHEME_LENGTH ]
                 != sal_Unicode( ':' ) )
         {
-            // Invaild (no ':' after <scheme>).
+            // Invalid (no ':' after <scheme>).
             return;
         }
 
         if ( m_aUri.getStr()[ TDOC_URL_SCHEME_LENGTH + 1 ]
                 != sal_Unicode( '/' ) )
         {
-            // Invaild (no '/' after <scheme>:).
+            // Invalid (no '/' after <scheme>:).
             return;
         }
 

Modified: openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/webdav/SerfSession.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/webdav/SerfSession.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/webdav/SerfSession.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucb/source/ucp/webdav/SerfSession.cxx Mon Aug  1 04:31:52 2016
@@ -1404,7 +1404,7 @@ bool containsLocktoken( const uno::Seque
 
 // -------------------------------------------------------------------
 // This method doesn't seem to be used.
-// In any case the default behavior is to ask a lock whith a life of 3 minutes
+// In any case the default behavior is to ask a lock with a life of 3 minutes
 // it will then be refreshed automatically (see SerfLockStore class)
 // In case of AOO crash the lock will expire by itself
 bool SerfSession::removeExpiredLocktoken( const rtl::OUString & /*inURL*/,

Modified: openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx Mon Aug  1 04:31:52 2016
@@ -405,7 +405,7 @@ public:
       *        authentication-remember-mode for accounts preferred by the
       *        requesting client.
       * @param bCanUseSystemCredentials indicates whether issuer of the
-      *        authetication request can obtain and use system credentials
+      *        authentication request can obtain and use system credentials
       *        for authentication.
       * @param bDefaultUseSystemCredentials specifies the default system
       *        credentials usage preferred by the requesting client

Modified: openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultset.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultset.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultset.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultset.hxx Mon Aug  1 04:31:52 2016
@@ -558,7 +558,7 @@ public:
 	 * Note: An exception thrown to indicate an error must always be thrown
 	 * by the thread that created the data supplier. If the supplier collects
 	 * data asynchronously ( i.e. in a separate thread ) and an error
-	 * occures, throwing of the appropriate exception must be deferred
+	 * occurs, throwing of the appropriate exception must be deferred
 	 * until validate() is called by the ResultSet implementation from
 	 * inside the main thread.
 	 * In case data are obtained synchronously, the ResultSetException can

Modified: openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx Mon Aug  1 04:31:52 2016
@@ -123,7 +123,7 @@ private:
 
 public:
 	/**
-	  * Construtor.
+	  * Constructor.
 	  *
 	  * @param rxSMgr is a Service Manager.
 	  */
@@ -132,7 +132,7 @@ public:
 				com::sun::star::lang::XMultiServiceFactory >& rxSMgr );
 
 	/**
-	  * Construtor.
+	  * Constructor.
 	  *
 	  * @param rxSMgr is a Service Manager.
 	  * @param rCommand is the parameter for the open command that produces

Modified: openoffice/branches/gbuild-reintegration/main/unotools/source/config/configitem.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/unotools/source/config/configitem.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/unotools/source/config/dynamicmenuoptions.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/unotools/source/config/dynamicmenuoptions.cxx Mon Aug  1 04:31:52 2016
@@ -138,7 +138,7 @@ class SvtDynMenu
         //---------------------------------------------------------------------------------------------------------
         // append user specific menu entry
         // We must find unique name for it by using special prefix
-        // and next count of user setted entries!
+        // and next count of user set entries!
         // Look for double menu entries here too ... may be some seperator items are supeflous ...
         void AppendUserEntry( SvtDynMenuEntry& rEntry )
         {

Modified: openoffice/branches/gbuild-reintegration/main/unotools/source/config/startoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/unotools/source/config/startoptions.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/unotools/source/config/startoptions.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/unotools/source/config/startoptions.cxx Mon Aug  1 04:31:52 2016
@@ -128,7 +128,7 @@ class SvtStartOptions_Impl : public Conf
 
 		/*-****************************************************************************************************//**
 			@short		access method to get internal values
-			@descr		These method give us a chance to regulate acces to ouer internal values.
+			@descr		These method give us a chance to regulate access to ouer internal values.
 						It's not used in the moment - but it's possible for the feature!
 
 			@seealso	-

Modified: openoffice/branches/gbuild-reintegration/main/vcl/source/glyphs/graphite_layout.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/vcl/source/glyphs/graphite_layout.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/vcl/source/glyphs/graphite_layout.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/vcl/source/glyphs/graphite_layout.cxx Mon Aug  1 04:31:52 2016
@@ -107,7 +107,7 @@ namespace
     typedef ext_std::pair<gr::GlyphIterator, gr::GlyphIterator>       glyph_range_t;
     typedef ext_std::pair<gr::GlyphSetIterator, gr::GlyphSetIterator> glyph_set_range_t;
 
-    inline long round(const float n) {
+    inline long round2long(const float n) {
         return long(n + (n < 0 ? -0.5 : 0.5));
     }
 
@@ -294,8 +294,8 @@ GraphiteLayout::Glyphs::fill_from(gr::Se
         fMinX = std::min(aBounds.first, fMinX);
         fMaxX = std::max(aBounds.second, fMaxX);
     }
-    long nXOffset = round(fMinX * fScaling);
-    rWidth = round(fMaxX * fScaling) - nXOffset + nDxOffset;
+    long nXOffset = round2long(fMinX * fScaling);
+    rWidth = round2long(fMaxX * fScaling) - nXOffset + nDxOffset;
     if (rWidth < 0)
     {
         // This can happen when there was no base inside the range
@@ -406,7 +406,7 @@ std::pair<float,float> GraphiteLayout::G
         if (j + nDelta >= nGlyphs || j + nDelta < 0) // at rhs ltr,rtl
         {
             fNextOrigin = fSegmentAdvance;
-            nNextOrigin = round(fSegmentAdvance * fScaling + rDXOffset);
+            nNextOrigin = round2long(fSegmentAdvance * fScaling + rDXOffset);
             aBounds.second = std::max(fSegmentAdvance, aBounds.second);
         }
         else
@@ -414,7 +414,7 @@ std::pair<float,float> GraphiteLayout::G
             gr::GlyphInfo aNextGlyph = *(iGlyphs.first + j + nDelta);
             fNextOrigin = std::max(aNextGlyph.attachedClusterBase()->origin(), aNextGlyph.origin());
             aBounds.second = std::max(fNextOrigin, aBounds.second);
-            nNextOrigin = round(fNextOrigin * fScaling + rDXOffset);
+            nNextOrigin = round2long(fNextOrigin * fScaling + rDXOffset);
         }
         aBounds.first = std::min(aGlyph.origin(), aBounds.first);
         if ((signed)aGlyph.firstChar() < rArgs.mnEndCharPos &&
@@ -432,8 +432,8 @@ std::pair<float,float> GraphiteLayout::G
     // the origin of the first glyph of the next cluster ltr
     // rtl it is the origin of the 1st glyph of the cluster
     long nXPos = (bRtl)?
-        round(aFirstGlyph.attachedClusterBase()->origin() * fScaling) + rDXOffset :
-        round(aBounds.second * fScaling) + rDXOffset;
+        round2long(aFirstGlyph.attachedClusterBase()->origin() * fScaling) + rDXOffset :
+        round2long(aBounds.second * fScaling) + rDXOffset;
     // force the last char in range to have the width of the cluster
     if (bRtl)
     {
@@ -474,7 +474,7 @@ GraphiteLayout::Glyphs::append(gr::Segme
     }
     long glyphId = gi.glyphID();
     long deltaOffset = 0;
-    int glyphWidth = round(nextOrigin * scaling) - round(gi.origin() * scaling);
+    int glyphWidth = round2long(nextOrigin * scaling) - round2long(gi.origin() * scaling);
 #ifdef GRLAYOUT_DEBUG
     fprintf(grLog(),"c%d g%d gWidth%d x%f ", firstChar, (int)gi.logicalIndex(), glyphWidth, nextOrigin);
 #endif
@@ -513,11 +513,11 @@ GraphiteLayout::Glyphs::append(gr::Segme
     nGlyphFlags |= (gi.directionLevel() & 0x1)? GlyphItem::IS_RTL_GLYPH : 0;
     GlyphItem aGlyphItem(size(),//gi.logicalIndex(),
         glyphId,
-        Point(round(gi.origin() * scaling + rDXOffset),
-            round((-gi.yOffset() * scaling) - segment.AscentOffset()* scaling)),
+        Point(round2long(gi.origin() * scaling + rDXOffset),
+            round2long((-gi.yOffset() * scaling) - segment.AscentOffset()* scaling)),
         nGlyphFlags,
         glyphWidth);
-    aGlyphItem.mnOrigWidth = round(gi.advanceWidth() * scaling);
+    aGlyphItem.mnOrigWidth = round2long(gi.advanceWidth() * scaling);
     push_back(aGlyphItem);
 
     // update the offset if this glyph was dropped

Propchange: openoffice/branches/gbuild-reintegration/test/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  1 04:31:52 2016
@@ -11,3 +11,4 @@
 /openoffice/branches/ia2/test:1417739-1541842
 /openoffice/branches/rejuvenate01/test:1534063
 /openoffice/branches/sidebar/test:1415095-1466374
+/openoffice/trunk/test:1731503-1737137

Modified: openoffice/branches/gbuild-reintegration/test/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/test/build.xml?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/test/build.xml (original)
+++ openoffice/branches/gbuild-reintegration/test/build.xml Mon Aug  1 04:31:52 2016
@@ -145,10 +145,15 @@
 		</condition>
 
 		<!-- Next try the internal install path that the with-package-format=installed option to configure uses -->
-		<available type="dir" file="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/openoffice4/program"
-			property="internalInstalledDir" value="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/openoffice4/program"/>
-		<condition property="test.arg0" value="-Dopenoffice.home=${internalInstalledDir}">
-			<isset property="internalInstalledDir" />
+		<available type="dir" file="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/openoffice4"
+			property="internalInstalledDirNix" value="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/openoffice4"/>
+		<condition property="test.arg0" value="-Dopenoffice.home=${internalInstalledDirNix}">
+			<isset property="internalInstalledDirNix" />
+		</condition>
+		<available type="dir" file="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/OpenOffice 4"
+			property="internalInstalledDirWin" value="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/installed/install/en-US/OpenOffice 4"/>
+		<condition property="test.arg0" value="-Dopenoffice.home=${internalInstalledDirWin}">
+			<isset property="internalInstalledDirWin" />
 		</condition>
 
 		<!-- Finally try the tar.gz and zip archives which build by default -->

Modified: openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/Run.help
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/Run.help?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/Run.help (original)
+++ openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/Run.help Mon Aug  1 04:31:52 2016
@@ -20,4 +20,4 @@ Example
 	run -Dopenoffice.home=/Applications/OpenOffice.org.app/Contents -tp bvt
 	run -Dopenoffice.home=/Applications/OpenOffice.org.app/Contents -tc bvt:bvt.gui.BasicFunctionTest,bvt.gui.FileTypeTest
 	run -Dopenoffice.pack=http://ci.apache.org/projects/openoffice/install/linux64/Apache_OpenOffice_4.0.0_Linux_x86-64_install-arc_en-US.tar.gz -tp bvt
-	
\ No newline at end of file
+

Modified: openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/common/Installer.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/common/Installer.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/common/Installer.java (original)
+++ openoffice/branches/gbuild-reintegration/test/testcommon/source/org/openoffice/test/common/Installer.java Mon Aug  1 04:31:52 2016
@@ -47,6 +47,28 @@ public class Installer implements Runnab
 				throw new RuntimeException("Only allow one running test instance!");
 			}
 		}
+
+		prop = findOpenofficeHome();
+		System.setProperty("openoffice.home", prop);
+		log.log(Level.INFO, MessageFormat.format("OpenOffice in {0} will be tested.", prop));
+
+		String[] jars = { "juh.jar", "unoil.jar", "ridl.jar", "jurt.jar" };
+		for (String jar : jars) {
+			File file = FileUtil.findFile(prop, jar);
+
+			if (file != null)
+				addToClassPath(file);
+		}
+
+	}
+
+	private String findOpenofficeHome() {
+		String prop = System.getProperty("openoffice.home");
+		if (prop != null) {
+			validateOpenOfficeInstallation(new File(prop));
+			return prop;
+		}
+
 		if ((prop = System.getProperty("openoffice.pack")) != null) {
 			String onlyNewProp = System.getProperty("only.new");
 			File packFile = null;
@@ -92,33 +114,46 @@ public class Installer implements Runnab
 				if (files != null && files.length == 1 && files[0].isDirectory()) {
 					files[0].renameTo(installDir);
 				}
-				System.setProperty("openoffice.home", installDir.getAbsolutePath());
+				validateOpenOfficeInstallation(installDir);
+				return installDir.getAbsolutePath();
 			} finally {
 				FileUtil.deleteFile(installTempDir);
 			}
 		}
 
-		prop = System.getProperty("openoffice.home", installDir.getAbsolutePath());
-		File sofficeBin = FileUtil.findFile(new File(prop), "soffice.bin", false);
-		if (sofficeBin == null)
-			throw new RuntimeException(MessageFormat.format(
-					"No valid OpenOffice is found in {0}! Use system property openoffice.home to specify a valid OpenOffice installation directory.", prop));
-		try {
-			prop = sofficeBin.getParentFile().getParentFile().getCanonicalPath();
-			System.setProperty("openoffice.home", prop);
-			log.log(Level.INFO, MessageFormat.format("OpenOffice in {0} will be tested.", prop));
-		} catch (IOException e) {
-			// ignore, never occurs
+		// Try look for the output of ./configure --with-package-format="installed"
+		final String srcRoot = System.getenv("SRC_ROOT");
+		final String inPath = System.getenv("INPATH");
+		if (srcRoot == null || inPath == null) {
+			throw new RuntimeException("Neither openoffice.home nor openoffice.pack were specified, and could not autodetect OpenOffice " +
+				"from ${SRC_ROOT} and ${INPATH}. Please make sure OpenOffice was built with the --with-package-format=\"installed\" option, " +
+				"and you ran \"source <platform>.set.sh\"");
 		}
-
-		String[] jars = { "juh.jar", "unoil.jar", "ridl.jar", "jurt.jar" };
-		for (String jar : jars) {
-			File file = FileUtil.findFile(prop, jar);
-
-			if (file != null)
-				addToClassPath(file);
+		final File instsetoo_native = new File(srcRoot, "instsetoo_native");
+		final File buildDir = new File(instsetoo_native, inPath);
+		final File apacheOpenOffice = new File(buildDir, "Apache_OpenOffice");
+		final File installed = new File(apacheOpenOffice, "installed");
+		final File install = new File(installed, "install");
+		final File enUs = new File(install, "en-US");
+		// *nix:
+		File openoffice4 = new File(enUs, "openoffice4");
+		if (!openoffice4.exists()) {
+			// Windows:
+			openoffice4 = new File(enUs, "OpenOffice 4");
+		}
+		if (!openoffice4.exists()) {
+			throw new RuntimeException("Neither openoffice.home nor openoffice.pack were specified, and could not find OpenOffice in " + openoffice4.getAbsolutePath());
 		}
+		validateOpenOfficeInstallation(openoffice4);
+		return openoffice4.getAbsolutePath();
+	}
 
+	private static void validateOpenOfficeInstallation(File directory) {
+		final File sofficeBin = FileUtil.findFile(directory, "soffice.bin", false);
+		if (sofficeBin == null) {
+			throw new RuntimeException(MessageFormat.format(
+				"No valid OpenOffice found in {0}!", directory.getAbsolutePath()));
+		}
 	}
 
 	public static boolean addToClassPath(File file) {

Modified: openoffice/branches/gbuild-reintegration/test/testgui/source/bvt/gui/BasicFunctionTest.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/test/testgui/source/bvt/gui/BasicFunctionTest.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/test/testgui/source/bvt/gui/BasicFunctionTest.java (original)
+++ openoffice/branches/gbuild-reintegration/test/testgui/source/bvt/gui/BasicFunctionTest.java Mon Aug  1 04:31:52 2016
@@ -705,7 +705,7 @@ public class BasicFunctionTest {
 		// SC_FunctionWizardDlg_FunctionList.doubleClick(5, 5);
 		scFunctionWizardDlgFunctionList.select("ABS");
 		scFunctionWizardDlgNext.click(); // Use "Next" button
-		scFunctionWizardDlgEdit1.inputKeys("A1");
+		scFunctionWizardDlgEdit1.typeKeys("A1");
 		scFunctionWizardDlg.ok();
 		// Verify if the calculated result is equal to the expected result
 		assertEquals("The calculated result", expectedResult, SCTool.getCellText("B1"));
--- openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/filtergrouping.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/filtergrouping.cxx Mon Aug  1 04:31:52 2016
@@ -114,7 +114,7 @@ namespace sfx2
 	the filter itself) nor indirectly (as part of another local group).</p>
 
 	<p>The only exception are filters which are part of a global class <em>and</em> a local class. This is allowed.
-	Beeing cotained in two local classes isn't.</p>
+	Being cotained in two local classes isn't.</p>
 
 	<p>So that's all what you need to know: Understand the concept of "filter classes" (a filter class combines
 	different filters and acts as if it's a filter itself) and the concept of groups (a group just describes a
@@ -441,7 +441,7 @@ namespace sfx2
 						||	( s_cWildcardSeparator == pBuffer[ nExistentWCEnd ] )
 						)
 					{	// it's really the complete wildcard we found
 						// (not something like _rWC beeing "*.t" and _rToBeExtended containing "*.txt")
 						// -> outta here
 						return;
 					}
@@ -441,7 +441,7 @@ namespace sfx2
 						)
 					{	// it's really the complete wildcard we found
-						// (not something like _rWC beeing "*.t" and _rToBeExtended containing "*.txt")
+						// (not something like _rWC being "*.t" and _rToBeExtended containing "*.txt")
 						// -> outta here
 						return;

Modified: openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/partwnd.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/sfx2/source/dialog/partwnd.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/unotools/source/config/configitem.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/unotools/source/config/configitem.cxx Mon Aug  1 04:31:52 2016
@@ -799,8 +799,8 @@ void lcl_normalizeLocalNames(Sequence< O
                 break;
             }
         }
-        OSL_ENSURE(false, "Cannot create absolute pathes: missing interface");
-        // make local pathes instaed
+        OSL_ENSURE(false, "Cannot create absolute paths: missing interface");
+        // make local paths instaed
 
     case CONFIG_NAME_LOCAL_PATH:
         {

Modified: openoffice/branches/gbuild-reintegration/main/unotools/source/config/configpathes.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/unotools/source/config/configpathes.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/unotools/source/config/configpathes.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/unotools/source/config/configpathes.cxx Mon Aug  1 04:31:52 2016
@@ -121,7 +121,7 @@ sal_Bool splitLastFromConfigurationPath(
         {
             nPos =  _sInPath.lastIndexOf('/',nPos);
         }
-        else // defined behavior for invalid pathes
+        else // defined behavior for invalid paths
         {
             nStart = 0, nEnd = _sInPath.getLength();
             nPos = -1;
@@ -202,7 +202,7 @@ sal_Int32 lcl_findPrefixEnd(OUString con
     sal_Int32 nPrefixLength = _sPrefixPath.getLength();
 
     OSL_ENSURE(nPrefixLength == 0 || _sPrefixPath[nPrefixLength-1] != '/',
-                "Cannot handle slash-terminated prefix pathes");
+                "Cannot handle slash-terminated prefix paths");
         
     sal_Bool bIsPrefix;
     if (_sNestedPath.getLength() > nPrefixLength)

Modified: openoffice/branches/gbuild-reintegration/main/unotools/source/config/dynamicmenuoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/unotools/source/config/dynamicmenuoptions.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================